@@ -65,6 +65,12 @@ whatNWISdata <- function(..., convertType=TRUE){
   
   if("service" %in% names(matchReturn)){
     service <- matchReturn$service
+    if(any(service %in% c("qw", "qwdata"))){
+      .Deprecated(old = "whatNWISdata", package = "dataRetrieval", 
+                  new = "whatWQPdata",
+                  msg = "NWIS qw web services are being retired. Please see the vignette 
+'Changes to NWIS QW services' for more information.")
+    }
   } else {
     service <- "all"
   }
@@ -78,6 +84,7 @@ whatNWISdata <- function(..., convertType=TRUE){
   
   if("parameterCd" %in% names(matchReturn)){
     parameterCd <- matchReturn$parameterCd
+    matchReturn[["parameterCd"]] <- NULL
   } else {
     parameterCd <- "all"
   }
